#' A dataset containing only 1000 raws of the ECH 2018
#' @family dataset
#' @format A data frame with 1000 rows and 579 variables:
#' \describe{
#'   \item{numero}{household id}
#'   \item{nper}{ }
#'   \item{anio}{ }
#'   \item{mes}{ }
#'   \item{dpto}{ }
#'   \item{nomdpto}{ }
#'   \item{secc}{ }
#'   \item{segm}{ }
#'   \item{loc_agr_13}{ }
#'   \item{nom_loc_agr_13}{ }
#'   \item{ccz}{ }
#'   \item{barrio}{ }
#'   \item{nombarrio}{ }
#'   \item{estred13}{ }
#'   \item{region_3}{ }
#'   \item{region_4}{ }
#'   \item{pesoano}{ }
#'   \item{pesotri}{ }
#'   \item{pesomen}{ }
#'   \item{c1}{ }
#'   \item{c2}{ }
#'   \item{c3}{ }
#'   \item{c4}{ }
#'   \item{c5_1}{ }
#'   \item{c5_2}{ }
#'   \item{c5_3}{ }
#'   \item{c5_4}{ }
#'   \item{c5_5}{ }
#'   \item{c5_6}{ }
#'   \item{c5_7}{ }
#'   \item{c5_8}{ }
#'   \item{c5_9}{ }
#'   \item{c5_10}{ }
#'   \item{c5_11}{ }
#'   \item{c5_12}{ }
#'   \item{c6}{ }
#'   \item{d8_1}{ }
#'   \item{d8_2}{ }
#'   \item{d8_3}{ }
#'   \item{d8_4}{ }
#'   \item{d9}{ }
#'   \item{d10}{ }
#'   \item{d11}{ }
#'   \item{d12}{ }
#'   \item{d13}{ }
#'   \item{d14}{ }
#'   \item{d15}{ }
#'   \item{d16}{ }
#'   \item{d18}{ }
#'   \item{d260}{ }
#'   \item{d19}{ }
#'   \item{d20}{ }
#'   \item{d21_1}{ }
#'   \item{d21_2}{ }
#'   \item{d21_3}{ }
#'   \item{d21_4}{ }
#'   \item{d21_4_1}{ }
#'   \item{d21_5}{ }
#'   \item{d21_5_1}{ }
#'   \item{d21_6}{ }
#'   \item{d21_20}{ }
#'   \item{d21_7}{ }
#'   \item{d21_8}{ }
#'   \item{d21_9}{ }
#'   \item{d21_10}{ }
#'   \item{d21_11}{ }
#'   \item{d21_12}{ }
#'   \item{d21_13}{ }
#'   \item{d21_14}{ }
#'   \item{d21_14_1}{ }
#'   \item{d21_15}{ }
#'   \item{d21_15_1}{ }
#'   \item{d21_15_2}{ }
#'   \item{d21_15_3}{ }
#'   \item{d21_15_4}{ }
#'   \item{d21_15_5}{ }
#'   \item{d21_15_6}{ }
#'   \item{d21_16}{ }
#'   \item{d21_16_1}{ }
#'   \item{d21_16_2}{ }
#'   \item{d21_17}{ }
#'   \item{d21_18}{ }
#'   \item{d21_18_1}{ }
#'   \item{d21_19}{ }
#'   \item{d21_19_1}{ }
#'   \item{d181}{ }
#'   \item{d229}{ }
#'   \item{d230}{ }
#'   \item{d231}{ }
#'   \item{d232}{ }
#'   \item{d184}{ }
#'   \item{d184_1}{ }
#'   \item{d23}{ }
#'   \item{d24}{ }
#'   \item{d25}{ }
#'   \item{h155}{ }
#'   \item{h155_1}{ }
#'   \item{h156}{ }
#'   \item{h156_1}{ }
#'   \item{h252}{ }
#'   \item{h252_1}{ }
#'   \item{h158_1}{ }
#'   \item{h158_2}{ }
#'   \item{h159}{ }
#'   \item{h160}{ }
#'   \item{h160_1}{ }
#'   \item{h160_2}{ }
#'   \item{h161}{ }
#'   \item{h162}{ }
#'   \item{h163_1}{ }
#'   \item{h163_2}{ }
#'   \item{h164}{ }
#'   \item{h165}{ }
#'   \item{h227}{ }
#'   \item{h166}{ }
#'   \item{h269}{ }
#'   \item{h269_1}{ }
#'   \item{h167_1}{ }
#'   \item{h167_1_1}{ }
#'   \item{h167_1_2}{ }
#'   \item{h167_2}{ }
#'   \item{h167_2_1}{ }
#'   \item{h167_2_2}{ }
#'   \item{h167_3}{ }
#'   \item{h167_3_1}{ }
#'   \item{h167_3_2}{ }
#'   \item{h167_4}{ }
#'   \item{h167_4_1}{ }
#'   \item{h167_4_2}{ }
#'   \item{h169}{ }
#'   \item{h170_1}{ }
#'   \item{h170_2}{ }
#'   \item{h271}{ }
#'   \item{h271_1}{ }
#'   \item{h171}{ }
#'   \item{h171_1}{ }
#'   \item{h171_2}{ }
#'   \item{h172}{ }
#'   \item{h172_1}{ }
#'   \item{h173}{ }
#'   \item{h173_1}{ }
#'   \item{i228}{ }
#'   \item{i174}{ }
#'   \item{i259}{ }
#'   \item{i175}{ }
#'   \item{ht1}{ }
#'   \item{ht2}{ }
#'   \item{ht3}{ }
#'   \item{ht4}{ }
#'   \item{ht5}{ }
#'   \item{ht6}{ }
#'   \item{ht7}{ }
#'   \item{ht8}{ }
#'   \item{ht9}{ }
#'   \item{ht10}{ }
#'   \item{ht11}{ }
#'   \item{ht13}{ }
#'   \item{ht14}{ }
#'   \item{ht19}{ }
#'   \item{yhog}{ }
#'   \item{ysvl}{ }
#'   \item{lp_06}{ }
#'   \item{li_06}{ }
#'   \item{e557}{ }
#'   \item{e558}{ }
#'   \item{e26}{ }
#'   \item{e27}{ }
#'   \item{e29_1}{ }
#'   \item{e29_2}{ }
#'   \item{e29_3}{ }
#'   \item{e29_4}{ }
#'   \item{e29_5}{ }
#'   \item{e29_5_1}{ }
#'   \item{e29_6}{ }
#'   \item{e30}{ }
#'   \item{e31}{ }
#'   \item{e32}{ }
#'   \item{e33}{ }
#'   \item{e34}{ }
#'   \item{e35}{ }
#'   \item{e36}{ }
#'   \item{e185}{ }
#'   \item{e186_1}{ }
#'   \item{e186_2}{ }
#'   \item{e186_3}{ }
#'   \item{e186_4}{ }
#'   \item{e37}{ }
#'   \item{e37_2}{ }
#'   \item{e234_2}{ }
#'   \item{e38}{ }
#'   \item{e38_1}{ }
#'   \item{e39}{ }
#'   \item{e39_2}{ }
#'   \item{e235_2}{ }
#'   \item{e236}{ }
#'   \item{e236_2}{ }
#'   \item{e236_4}{ }
#'   \item{e45_1}{ }
#'   \item{e45_1_1}{ }
#'   \item{e45_1_1_1}{ }
#'   \item{e45_1_2}{ }
#'   \item{e45_1_2_1}{ }
#'   \item{e45_2}{ }
#'   \item{e45_2_1}{ }
#'   \item{e45_2_1_1}{ }
#'   \item{e45_2_2}{ }
#'   \item{e45_2_2_1}{ }
#'   \item{e45_3}{ }
#'   \item{e45_3_1}{ }
#'   \item{e45_3_1_1}{ }
#'   \item{e45_3_2}{ }
#'   \item{e45_3_2_1}{ }
#'   \item{e45_4}{ }
#'   \item{e45_4_1}{ }
#'   \item{e45_4_2}{ }
#'   \item{e45_4_3}{ }
#'   \item{e45_4_3_1}{ }
#'   \item{e45_5}{ }
#'   \item{e45_5_1}{ }
#'   \item{e45_5_1_1}{ }
#'   \item{e45_6}{ }
#'   \item{e45_7}{ }
#'   \item{e45_7_1}{ }
#'   \item{e237}{ }
#'   \item{e46}{ }
#'   \item{e47}{ }
#'   \item{e47_1}{ }
#'   \item{e190}{ }
#'   \item{e190_1}{ }
#'   \item{e190_1_1}{ }
#'   \item{e190_2}{ }
#'   \item{e190_2_1}{ }
#'   \item{e190_3}{ }
#'   \item{e190_3_1}{ }
#'   \item{e191}{ }
#'   \item{e192}{ }
#'   \item{e48}{ }
#'   \item{e49}{ }
#'   \item{e238}{ }
#'   \item{e239}{ }
#'   \item{e240_1}{ }
#'   \item{e240_2}{ }
#'   \item{e241}{ }
#'   \item{e242}{ }
#'   \item{e242_1}{ }
#'   \item{e193}{ }
#'   \item{e194}{ }
#'   \item{e243_1}{ }
#'   \item{e243_2}{ }
#'   \item{e244}{ }
#'   \item{e245}{ }
#'   \item{e245_1}{ }
#'   \item{e196}{ }
#'   \item{e196_1}{ }
#'   \item{e196_2}{ }
#'   \item{e196_3}{ }
#'   \item{e197}{ }
#'   \item{e197_1}{ }
#'   \item{e51_2}{ }
#'   \item{e51_3}{ }
#'   \item{e198}{ }
#'   \item{e199}{ }
#'   \item{e200}{ }
#'   \item{e200_1}{ }
#'   \item{e200_2}{ }
#'   \item{e200_3}{ }
#'   \item{e201}{ }
#'   \item{e201_1}{ }
#'   \item{e202_1}{ }
#'   \item{e202_2}{ }
#'   \item{e202_3}{ }
#'   \item{e202_4}{ }
#'   \item{e202_8}{ }
#'   \item{e202_5}{ }
#'   \item{e202_6}{ }
#'   \item{e202_6_1}{ }
#'   \item{e202_7}{ }
#'   \item{e51_4}{ }
#'   \item{e210_1}{ }
#'   \item{e51_5}{ }
#'   \item{e210_2}{ }
#'   \item{e51_6}{ }
#'   \item{e209_1}{ }
#'   \item{e210_3}{ }
#'   \item{e211}{ }
#'   \item{e211_1}{ }
#'   \item{e211_2}{ }
#'   \item{e211_3}{ }
#'   \item{e562}{ }
#'   \item{e212}{ }
#'   \item{e212_1}{ }
#'   \item{e213}{ }
#'   \item{e51_7}{ }
#'   \item{e51_7_1}{ }
#'   \item{e214_1}{ }
#'   \item{e215}{ }
#'   \item{e215_1}{ }
#'   \item{e216}{ }
#'   \item{e51_8}{ }
#'   \item{e217_1}{ }
#'   \item{e218}{ }
#'   \item{e218_1}{ }
#'   \item{e219}{ }
#'   \item{e51_9}{ }
#'   \item{e220_1}{ }
#'   \item{e221}{ }
#'   \item{e221_1}{ }
#'   \item{e222}{ }
#'   \item{e51_10}{ }
#'   \item{e223_1}{ }
#'   \item{e224}{ }
#'   \item{e224_1}{ }
#'   \item{e225}{ }
#'   \item{e51_11}{ }
#'   \item{e226_1}{ }
#'   \item{e559}{ }
#'   \item{e559_1}{ }
#'   \item{e559_2}{ }
#'   \item{e560}{ }
#'   \item{e560_1}{ }
#'   \item{e560_1_1}{ }
#'   \item{e560_2}{ }
#'   \item{e560_2_1}{ }
#'   \item{e561}{ }
#'   \item{e561_1}{ }
#'   \item{e59}{ }
#'   \item{e246}{ }
#'   \item{e246_1}{ }
#'   \item{e247}{ }
#'   \item{e60}{ }
#'   \item{e61}{ }
#'   \item{e248}{ }
#'   \item{e62}{ }
#'   \item{e249}{ }
#'   \item{e250}{ }
#'   \item{e64_1}{ }
#'   \item{e64_2}{ }
#'   \item{e64_3}{ }
#'   \item{e64_4}{ }
#'   \item{e64_5}{ }
#'   \item{e64_6}{ }
#'   \item{e64_7}{ }
#'   \item{e65}{ }
#'   \item{f66}{ }
#'   \item{f67}{ }
#'   \item{f261}{ }
#'   \item{f68}{ }
#'   \item{f69}{ }
#'   \item{f70}{ }
#'   \item{f71_2}{ }
#'   \item{f72_2}{ }
#'   \item{f73}{ }
#'   \item{f74}{ }
#'   \item{f75}{ }
#'   \item{f76_2}{ }
#'   \item{f262}{ }
#'   \item{f263}{ }
#'   \item{f264}{ }
#'   \item{f264_1}{ }
#'   \item{f265}{ }
#'   \item{f265_1}{ }
#'   \item{f77}{ }
#'   \item{f78}{ }
#'   \item{f79}{ }
#'   \item{f79_1}{ }
#'   \item{f80}{ }
#'   \item{f80_2}{ }
#'   \item{f81}{ }
#'   \item{f82}{ }
#'   \item{f83}{ }
#'   \item{f84}{ }
#'   \item{f266}{ }
#'   \item{f267}{ }
#'   \item{f268}{ }
#'   \item{f85}{ }
#'   \item{f86}{ }
#'   \item{f87}{ }
#'   \item{f88_1}{ }
#'   \item{f88_2}{ }
#'   \item{f89}{ }
#'   \item{f90_2}{ }
#'   \item{f91_2}{ }
#'   \item{f92}{ }
#'   \item{f93}{ }
#'   \item{f94}{ }
#'   \item{f94_2}{ }
#'   \item{f95}{ }
#'   \item{f96}{ }
#'   \item{f97}{ }
#'   \item{f98}{ }
#'   \item{f99}{ }
#'   \item{f100}{ }
#'   \item{f101}{ }
#'   \item{f102}{ }
#'   \item{f103}{ }
#'   \item{f104}{ }
#'   \item{f105}{ }
#'   \item{f106}{ }
#'   \item{f107}{ }
#'   \item{f108}{ }
#'   \item{f109}{ }
#'   \item{f110}{ }
#'   \item{f111}{ }
#'   \item{f112}{ }
#'   \item{f113}{ }
#'   \item{f114}{ }
#'   \item{f115}{ }
#'   \item{f116}{ }
#'   \item{f117}{ }
#'   \item{f118_1}{ }
#'   \item{f118_2}{ }
#'   \item{f119_2}{ }
#'   \item{f120_2}{ }
#'   \item{f121}{ }
#'   \item{f122}{ }
#'   \item{f123}{ }
#'   \item{f124_1}{ }
#'   \item{f124_2}{ }
#'   \item{f124_3}{ }
#'   \item{f124_4}{ }
#'   \item{f124_5}{ }
#'   \item{f125}{ }
#'   \item{g_id_1}{ }
#'   \item{g_id_2}{ }
#'   \item{g_id_3}{ }
#'   \item{g_id_1a}{ }
#'   \item{g_id_2a}{ }
#'   \item{g_id_3a}{ }
#'   \item{g126_1}{ }
#'   \item{g126_2}{ }
#'   \item{g126_3}{ }
#'   \item{g126_4}{ }
#'   \item{g126_5}{ }
#'   \item{g126_6}{ }
#'   \item{g126_7}{ }
#'   \item{g126_8}{ }
#'   \item{g250_1}{ }
#'   \item{g250_2}{ }
#'   \item{g250_5}{ }
#'   \item{g250_3}{ }
#'   \item{g250_4}{ }
#'   \item{g127}{ }
#'   \item{g127_1}{ }
#'   \item{g127_2}{ }
#'   \item{g127_3}{ }
#'   \item{g128}{ }
#'   \item{g128_1}{ }
#'   \item{g129}{ }
#'   \item{g129_1}{ }
#'   \item{g129_2}{ }
#'   \item{g130}{ }
#'   \item{g130_1}{ }
#'   \item{g131}{ }
#'   \item{g131_1}{ }
#'   \item{g132}{ }
#'   \item{g132_1}{ }
#'   \item{g132_2}{ }
#'   \item{g132_3}{ }
#'   \item{g133}{ }
#'   \item{g133_1}{ }
#'   \item{g133_2}{ }
#'   \item{g_st_1}{ }
#'   \item{g134_1}{ }
#'   \item{g134_2}{ }
#'   \item{g134_3}{ }
#'   \item{g134_4}{ }
#'   \item{g134_5}{ }
#'   \item{g134_6}{ }
#'   \item{g134_7}{ }
#'   \item{g134_8}{ }
#'   \item{g251_1}{ }
#'   \item{g251_2}{ }
#'   \item{g251_3}{ }
#'   \item{g251_4}{ }
#'   \item{g251_5}{ }
#'   \item{g135}{ }
#'   \item{g135_1}{ }
#'   \item{g135_2}{ }
#'   \item{g135_3}{ }
#'   \item{g136}{ }
#'   \item{g136_1}{ }
#'   \item{g137}{ }
#'   \item{g137_1}{ }
#'   \item{g137_2}{ }
#'   \item{g138}{ }
#'   \item{g138_1}{ }
#'   \item{g139}{ }
#'   \item{g139_1}{ }
#'   \item{g140}{ }
#'   \item{g140_1}{ }
#'   \item{g140_2}{ }
#'   \item{g140_3}{ }
#'   \item{g141}{ }
#'   \item{g141_1}{ }
#'   \item{g141_2}{ }
#'   \item{g_itnd_1}{ }
#'   \item{g142}{ }
#'   \item{g_itnd_2}{ }
#'   \item{g143}{ }
#'   \item{g144}{ }
#'   \item{g144_1}{ }
#'   \item{g144_2_1}{ }
#'   \item{g144_2_2}{ }
#'   \item{g144_2_3}{ }
#'   \item{g144_2_4}{ }
#'   \item{g144_2_5}{ }
#'   \item{g_itnd_3}{ }
#'   \item{g145}{ }
#'   \item{g146}{ }
#'   \item{g147}{ }
#'   \item{g_it_1}{ }
#'   \item{g148_1_1}{ }
#'   \item{g148_1_2}{ }
#'   \item{g148_1_3}{ }
#'   \item{g148_1_4}{ }
#'   \item{g148_1_5}{ }
#'   \item{g148_1_6}{ }
#'   \item{g148_1_7}{ }
#'   \item{g148_1_8}{ }
#'   \item{g148_1_9}{ }
#'   \item{g148_1_12}{ }
#'   \item{g148_1_10}{ }
#'   \item{g148_1_11}{ }
#'   \item{g_it_2}{ }
#'   \item{g148_2_1}{ }
#'   \item{g148_2_2}{ }
#'   \item{g148_2_3}{ }
#'   \item{g148_2_4}{ }
#'   \item{g148_2_5}{ }
#'   \item{g148_2_6}{ }
#'   \item{g148_2_7}{ }
#'   \item{g148_2_8}{ }
#'   \item{g148_2_9}{ }
#'   \item{g148_2_12}{ }
#'   \item{g148_2_10}{ }
#'   \item{g148_2_11}{ }
#'   \item{g148_3}{ }
#'   \item{g148_4}{ }
#'   \item{g148_5_1}{ }
#'   \item{g148_5_2}{ }
#'   \item{g149}{ }
#'   \item{g149_1}{ }
#'   \item{g150}{ }
#'   \item{g255}{ }
#'   \item{g256}{ }
#'   \item{g152}{ }
#'   \item{g151_5}{ }
#'   \item{g151_1}{ }
#'   \item{g151_2}{ }
#'   \item{g151_3}{ }
#'   \item{g151_3_1}{ }
#'   \item{g151_4}{ }
#'   \item{g257}{ }
#'   \item{g153}{ }
#'   \item{g153_1}{ }
#'   \item{g153_2}{ }
#'   \item{g258}{ }
#'   \item{g258_1}{ }
#'   \item{g154}{ }
#'   \item{g154_1}{ }
#'   \item{pobpcoac}{ }
#'   \item{subempleo}{ }
#'   \item{mto_cuota}{ }
#'   \item{mto_emer}{ }
#'   \item{mto_hogcon}{ }
#'   \item{mto_desay}{ }
#'   \item{mto_almue}{ }
#'   \item{mto_vacas}{ }
#'   \item{mto_oveja}{ }
#'   \item{mto_caball}{ }
#'   \item{lecheenpol}{ }
#'   \item{indaceliac}{ }
#'   \item{indaucc}{ }
#'   \item{indaemer}{ }
#'   \item{pt1}{ }
#'   \item{pt2}{ }
#'   \item{pt4}{ }
#'   \item{pobre06}{ }
#'   \item{indigente06}{ }
#'   \item{upm_id}{ }
#'   \item{estrato}{ }
#'   ...
#' }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"toy_ech_2018"


#' A dataset containing only 1000 raws of the ECH 2018 income variables
#' @family dataset
#' @format A data frame with 1000 rows and 9 variables:
#' \describe{
#'   \item{numero}{household id}
#'   \item{mes}{}
#'   \item{ht11}{}
#'   \item{ysvl}{}
#'   \item{ht13}{}
#'   \item{ht19}{}
#'   \item{dpto}{}
#'   \item{pesoano}{}
#'   \item{estred13}{}
#'   \item{anio}{}
#'   \item{region_4}{}
#'   ...
#' }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"toy_ech_2018_income"



#' A dataset containing variables names change of the ECH 2006-2018
#' @family dataset
#' @format A data frame with 976 rows and 21 variables:
#' \describe{
#'   \item{codigos}{Code oh label}
#'   \item{descripcion}{Description of label}
#'   \item{modulo}{Module in the form 2017}
#'   \item{obs}{Observations}
#'   \item{unidad}{Level of variable household (H) individual (P) or general (G)}
#'   \item{var06}{ECH variables names 2006}
#'   \item{var07}{ECH variables names 2007}
#'   \item{var08}{ECH variables names 2008}
#'   \item{var09}{ECH variables names 2009}
#'   \item{var10}{ECH variables names 2010}
#'   \item{var11}{ECH variables names 2011}
#'   \item{var12}{ECH variables names 2012}
#'   \item{var13}{ECH variables names 2013}
#'   \item{var14}{ECH variables names 2014}
#'   \item{var15}{ECH variables names 2015}
#'   \item{var16}{ECH variables names 2016}
#'   \item{var17}{ECH variables names 2017}
#'   \item{var18}{ECH variables names 2018}
#'   \item{var19}{ECH variables names 2019}
#'   \item{var21}{ECH variables names 2021 segundo semestre}
#'   \item{var22}{ECH variables names 2022 primer semestre}
#'   ...
#'}
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"dic"


#' A dataset containing the IPC base 2010 only for the Interior region
#' @family dataset
#' @format A data frame with 120 rows and 2 variables:
#' \describe{
#'   \item{fecha}{date from 2011 to 2019}
#'   \item{indice}{IPC}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"ipc_base2010_int"

#' A dataset containing the IPC base 2010 only for the Montevideo region
#' @family dataset
#' @format A data frame with 120 rows and 2 variables:
#' \describe{
#'   \item{fecha}{date from 2011 to 2019}
#'   \item{indice}{IPC}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"ipc_base2010_mdeo"

#' A dataset containing the CBA and CBNA for the Montevideo region
#' @family dataset
#' @format A data frame with 234 rows and 4 variables:
#' \describe{
#'   \item{fecha}{date from 2001 to 2020}
#'   \item{cba_li}{CBA}
#'   \item{cbna}{CBNA}
#'   \item{cbt_lp}{CBT}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"cba_cbna_mdeo"

#' A dataset containing the CBA and CBNA for the Interior Urbano region
#' @family dataset
#' @format A data frame with 234 rows and 4 variables:
#' \describe{
#'   \item{fecha}{date from 2001 to 2020}
#'   \item{cba_li}{CBA}
#'   \item{cbna}{CBNA}
#'   \item{cbt_lp}{CBT}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"cba_cbna_int"


#' A dataset containing the CBA and CBNA for the Interior Rural region
#' @family dataset
#' @format A data frame with 234 rows and 4 variables:
#' \describe{
#'   \item{fecha}{date from 2001 to 2020}
#'   \item{cba_li}{CBA}
#'   \item{cbna}{CBNA}
#'   \item{cbt_lp}{CBT}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"cba_cbna_rur"


#' A dataset containing the IPAB
#' @family dataset
#' @format A data frame with 286 rows and 2 variables:
#' \describe{
#'   \item{fecha}{date from 1997 to 2020}
#'   \item{indice}{IPAB}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"ipab_base2010"

#' A dataset containing the IPAB for the Interior region
#' @family dataset
#' @format A data frame with 108 rows and 2 variables:
#' \describe{
#'   \item{fecha}{date from 2011 to 2019}
#'   \item{indice}{IPAB}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"ipab_base2010_int"

#' A dataset containing the IPAB for the Montevideo region
#' @family dataset
#' @format A data frame with 108 rows and 2 variables:
#' \describe{
#'   \item{fecha}{date from 2011 to 2019}
#'   \item{indice}{IPAB}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"ipab_base2010_mdeo"


#' A dataset containing the urls of INE datasets and diccionaries
#' @family dataset
#' @format A data frame with 9 rows and 4 variables:
#' \describe{
#'   \item{yy}{date from 2011 to 2019}
#'   \item{md_sav}{url for microdata download}
#'   \item{upm_sav}{url for upm download}
#'   \item{dic}{url for dictionary download}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"urls_ine"

#' A dataset containing the IPC base 2010
#' @family dataset
#' @format A data frame with 990 rows and 5 variables:
#' \describe{
#'   \item{fecha}{date from 1937 to 2019}
#'   \item{indice}{IPC}
#'   \item{mensual}{mensual value of IPC}
#'   \item{trimestre}{three-month period value of IPC}
#'   \item{cuatrimestre}{four-month period value of IPC}
#'   \item{semestre}{six-month period value of IPC}
#'   \item{acum_ano}{acumulated IPC}
#'   \item{acum_12_meses}{acumulated IPC last 12 month}
#'  }
#' @source \url{https://www.gub.uy/instituto-nacional-estadistica/}
#' @details
#' Disclaimer: This script is not an official INE product.
#' Aviso: El script no es un producto oficial de INE.
"ipc_base2010"
